"""
Ce fichier permet de gérer tout ce qui est lié
a un appel d'offre.

Pour memo appel d'offre est le moyen par le quel une société va soliciter des
organismes de formation pour repondre à un besoin de formation
"""
import pymongo
from pymongo import MongoClient
import json
from bson import ObjectId
import re
from datetime import datetime
import prj_common as mycommon
import secrets
import inspect
import sys, os
import csv
import pandas as pd
from pymongo import ReturnDocument
import GlobalVariable as MYSY_GV
from math import isnan
import GlobalVariable as MYSY_GV
import ela_index_bdd_classes as eibdd
import email_mgt as email

def Add_Appel_Offre(diction):
    try:
        diction = mycommon.strip_dictionary(diction)

        """
        Verification des input acceptés
        """
        field_list = ['token', 'nom', 'prenom', 'email', 'tel_mobile', 'date_naissance', 'adr_rue', 'adr_ville',
                      'adr_code_postal', 'adr_pays']
        incom_keys = diction.keys()
        for val in incom_keys:
            if val not in field_list:
                mycommon.myprint(str(
                    inspect.stack()[0][3]) + "  Le champ  '" + val + "' n'existe pas")
                return False, " Les informations fournies sont incorrectes",

        """
        Verification des champs obligatoires
        """
        field_list_obligatoire = ['token', 'nom', 'prenom', 'email', 'tel_mobile', ]
        for val in field_list_obligatoire:
            if val not in diction:
                mycommon.myprint(
                    str(inspect.stack()[0][3]) + " - La valeur '" + val + "' n'est pas presente dans liste ")
                return False, " Les informations fournies sont incorrectes",

        """
        Verification de l'identité et autorisation de l'entité qui
        appelle cette API
        """
        token = ""
        if ("token" in diction.keys()):
            if diction['token']:
                token = diction['token']

        partner_recid = mycommon.get_parnter_recid_from_token(token)
        if (partner_recid is False):
            mycommon.myprint(
                str(inspect.stack()[0][3]) + " - partner_recid est KO. Les données de connexion sont incorrectes ")
            return False, " Vous n'etes pas autorisé à utiliser cette API "

        # Recuperation des données du partenaire
        local_status, my_partner = mycommon.get_partner_data_from_recid(partner_recid)
        if (local_status is False):
            mycommon.myprint(str(inspect.stack()[0][3]) + " - impossible de recuperer les données du partenaire")
            return False, str(inspect.stack()[0][3]) + "  - impossible de recuperer les données du partenaire. "

        """
                Recuperation des données fournies en entrée
                """
        data = {}
        data['partner_recid'] = diction['partner_recid']
        nom = ""
        if ("nom" in diction.keys()):
            if diction['nom']:
                nom = diction['nom']
                data['nom'] = diction['nom']

        return True, " L'appel d'ofre a été correctement créé"

    except Exception as e:
        exc_type, exc_obj, exc_tb = sys.exc_info()
        mycommon.myprint(str(inspect.stack()[0][3]) + " -" + str(e) + " - Line : " + str(exc_tb.tb_lineno))
        return False, " Impossible d'ajouter l'appel d'offre "


"""
Mise à jour d'un appel d'offre
"""
def Update_Appel_Offre(diction):

    try:
        diction = mycommon.strip_dictionary(diction)

        """
               Verification des input acceptés
               """
        field_list = ['token', 'nom', 'prenom', 'email', 'tel_mobile', 'date_naissance', 'adr_rue', 'adr_ville',
                      'adr_code_postal', 'adr_pays']
        incom_keys = diction.keys()
        for val in incom_keys:
            if val not in field_list:
                mycommon.myprint(str(
                    inspect.stack()[0][3]) + "  Le champ  '" + val + "' n'existe pas")
                return False, " Les informations fournies sont incorrectes",

        """
        Verification des champs obligatoires
        """
        field_list_obligatoire = ['token', 'email']
        for val in field_list_obligatoire:
            if val not in diction:
                mycommon.myprint(
                    str(inspect.stack()[0][3]) + " - La valeur '" + val + "' n'est pas presente dans liste ")
                return False, " Les informations fournies sont incorrectes",

        """
        Verification de l'identité et autorisation de l'entité qui
        appelle cette API
        """
        token = ""
        if ("token" in diction.keys()):
            if diction['token']:
                token = diction['token']

        partner_recid = mycommon.get_parnter_recid_from_token(token)
        if (partner_recid is False):
            mycommon.myprint(
                str(inspect.stack()[0][3]) + " - partner_recid est KO. Les données de connexion sont incorrectes ")
            return False, " Vous n'etes pas autorisé à utiliser cette API "

        # Recuperation des données du partenaire
        local_status, my_partner = mycommon.get_partner_data_from_recid(partner_recid)
        if (local_status is False):
            mycommon.myprint(str(inspect.stack()[0][3]) + " - impossible de recuperer les données du partenaire")
            return False, str(inspect.stack()[0][3]) + "  - impossible de recuperer les données du partenaire. "

        """
        Recuperation des données fournies en entrée
        """

        data = {}

        nom = ""
        if ("nom" in diction.keys()):
            nom = diction['nom']
            data['nom'] = diction['nom']

        """
                Clés de mise à jour 
                """
        date_cle = {}
        date_cle['email'] = str(email)
        date_cle['partner_recid'] = str(partner_recid)
        date_cle['valide'] = "1"
        date_cle['locked'] = "0"

        inserted_id = ""
        result = MYSY_GV.dbname['candidat'].find_one_and_update(
            date_cle,
            {"$set": data},
            upsert=False,
            return_document=ReturnDocument.AFTER
        )
        if (not result.acknowledged):
            mycommon.myprint(
                " Impossible de mettre à jour l'appel d'offre: " + str(email))
            return False, " Impossible de mettre à jour l'appel d'offre: " + str(email) + "  "

        return True, " L'appel d'offre  a été correctement mise à jour"

    except Exception as e:
        exc_type, exc_obj, exc_tb = sys.exc_info()
        mycommon.myprint(str(inspect.stack()[0][3]) + " -" + str(e) + " - Line : " + str(exc_tb.tb_lineno))
    return False, " Impossible d'ajouter le candidat "